import os

DATA_PATH = os.path.join(os.path.dirname(__file__), 'data')

with open(os.path.join(DATA_PATH, 'kite.txt')) as f:
    kite_text = f.read()

with open(os.path.join(DATA_PATH, 'kite_history.txt')) as f:
    kite_history = f.read()

harry_docs = ["The faster Harry got to the store, the faster and faster Harry would get home."]
harry_docs += ["Harry is hairy and faster than Jill."]
harry_docs += ["Jill is not as hairy as Harry."]



from __future__ import print_function, unicode_literals, division, absolute_import
# from builtins import int, round, str
from future import standard_library
standard_library.install_aliases()  # NOQA

import io

import mechanize
import cookielib
import pandas as pd

from secrets import accounts_google_pw, accounts_google_un


br = mechanize.Browser()
cj = cookielib.LWPCookieJar()
br.set_cookiejar(cj)

br.addheaders = [('User-agent', 'Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9.0.1) Gecko/2008071615 Fedora/3.0.1-1.fc9 Firefox/3.0.1')]
response = br.open('https://accounts.google.com/ServiceLogin?hl=en&continue=https://www.google.com/')
forms = mechanize.ParseResponse(response)
form = forms[0]
form['Email'] = accounts_google_un
form['Passwd'] = accounts_google_pw

response = br.open(form.click())

fstream = br.open("http://www.google.com/trends/trendsReport?q=SearchTerm&export=1")
df = pd.read_csv(io.StringIO(fstream.read()))
